@@ -1,4 +1,3 @@
-import json
 import sys
 
 from bgesdk.client import API
@@ -6,10 +5,13 @@ from bgesdk.error import APIError
 from bgesdk.management import constants
 from bgesdk.management.command import BaseCommand
 from bgesdk.management.utils import (
-    get_active_project, config_get, read_config, output
+    config_get,
+    get_active_project,
+    output,
+    output_json,
+    read_config
 )
 from bgesdk.models import ModelEncoder
-from bgesdk.version import __version__
 
 
 DEFAULT_OAUTH2_SECTION = constants.DEFAULT_OAUTH2_SECTION
@@ -18,8 +20,8 @@ DEFAULT_TOKEN_SECTION = constants.DEFAULT_TOKEN_SECTION
 
 class Command(BaseCommand):
 
-    order = 9
-    help='聚合组学数据（目前仅支持聚合数据流中符合平台设定 JSONPath 规则的数值型数据）。'
+    order = 12
+    help = '聚合组学数据（目前仅支持聚合数据流中符合平台设定 JSONPath 规则的数值型数据）。'
 
     def add_arguments(self, parser):
         parser.add_argument(
@@ -66,12 +68,6 @@ class Command(BaseCommand):
             default=100,
             help='聚合时间维度返回数。'
         )
-        parser.add_argument(
-            '--pretty',
-            default=False,
-            action='store_true',
-            help='打印可读性高的 JSON 字符串。'
-        )
         parser.add_argument(
             '-t',
             '--access_token',
@@ -80,7 +76,6 @@ class Command(BaseCommand):
         )
 
     def handler(self, args):
-        pretty = args.pretty
         access_token = args.access_token
         project = get_active_project()
         oauth2_section = DEFAULT_OAUTH2_SECTION
@@ -101,13 +96,10 @@ class Command(BaseCommand):
                 periods=args.periods
             )
         except APIError as e:
-            output('请求失败：{}'.format(e))
+            output('[red]请求失败：[/red]')
+            output_json(e.result)
             sys.exit(1)
-        if pretty:
-            result = json.dumps(
-                result, ensure_ascii=False, indent=4, cls=ModelEncoder
-            )
-        else:
-            result = json.dumps(result, ensure_ascii=False, cls=ModelEncoder)
-        output('请求成功，返回值：')
-        output(result)
+        output_json(
+            result,
+            cls=ModelEncoder
+        )
