@@ -1,4 +1,3 @@
-import json
 import sys
 
 from bgesdk.client import API
@@ -6,10 +5,13 @@ from bgesdk.error import APIError
 from bgesdk.management import constants
 from bgesdk.management.command import BaseCommand
 from bgesdk.management.utils import (
-    get_active_project, config_get, read_config, output
+    config_get,
+    get_active_project,
+    output,
+    output_json,
+    read_config
 )
 from bgesdk.models import ModelEncoder
-from bgesdk.version import __version__
 
 
 DEFAULT_OAUTH2_SECTION = constants.DEFAULT_OAUTH2_SECTION
@@ -19,15 +21,9 @@ DEFAULT_TOKEN_SECTION = constants.DEFAULT_TOKEN_SECTION
 class Command(BaseCommand):
 
     order = 1
-    help='获取用户信息。'
+    help = '获取用户信息。'
 
     def add_arguments(self, parser):
-        parser.add_argument(
-            '--pretty',
-            default=False,
-            action='store_true',
-            help='打印可读性高的 JSON 字符串。'
-        )
         parser.add_argument(
             '-t',
             '--access_token',
@@ -36,7 +32,6 @@ class Command(BaseCommand):
         )
 
     def handler(self, args):
-        pretty = args.pretty
         access_token = args.access_token
         project = get_active_project()
         oauth2_section = DEFAULT_OAUTH2_SECTION
@@ -49,17 +44,10 @@ class Command(BaseCommand):
         try:
             result = api.get_user()
         except APIError as e:
-            output('请求失败：{}'.format(e))
+            output('[red]请求失败：[/red]')
+            output_json(e.result)
             sys.exit(1)
-        if not result:
-            output('请求成功，返回值：')
-            output(result)
-            sys.exit(1)
-        if pretty:
-            result = json.dumps(
-                result, ensure_ascii=False, indent=4, cls=ModelEncoder
-            )
-        else:
-            result = json.dumps(result, ensure_ascii=False, cls=ModelEncoder)
-        output('请求成功，返回值：')
-        output(result)
+        output_json(
+            result,
+            cls=ModelEncoder
+        )
